==> audio-slice-0.0.2.tar.gz: audio-slice-0.0.2/README.md <==
# Audio Slice

## Description

This tool slices an MP3 file in to a specified number of pieces. Using this
command line tool, you can extract multiple audio files from one master file.

## Current Development Status

This tool is still in its early stages and can only be described as "quick and
dirty". You should be comfortable with everything that comes along with that
descriptor.

## Usage Dependencies

Here are the required dependencies to use this tool:

- [FFmpeg](https://www.ffmpeg.org/download.html)
- Python 2.7+

## Installation

The easiest way to install this tool is to use PIP. No other method of
installation is officially supported at this time.

- PIP ([OS/X Installation Instructions](https://ahmadawais.com/install-pip-macos-os-x-python/))

Installing Audio Slice can be achieved by running the following command once
you have PIP installed:

```
pip install audio-slice
```

## Usage

```
splice --piece <start_in_seconds> <end_in_seconds> <filename>
```

Example:
```
splice --piece 24.3 34.1 --piece 35.3 41.2 never_gonna_give_you_up.mp3
```

A few things to note about using the tool:

1. You can create as many slices of the audio as you need to; even if they overlap. You simply need to add another `--piece <start> <end>` option to the command line.
2. The tool will place the output files in the same directory as the input file.
3. You specify the start and end of a slice in seconds that can include greater precision. (_Ex: 74.3_)
4. Currently, this only works with MP3s.

==> audio-slice-0.0.3.tar.gz: audio-slice-0.0.3/README.md <==
# Audio Slice

## Description

This tool slices an MP3 file in to a specified number of pieces. Using this
command line tool, you can extract multiple audio files from one master file.

## Current Development Status

This tool is still in its early stages and can only be described as "quick and
dirty". You should be comfortable with everything that comes along with that
descriptor.

## Usage Dependencies

Here are the required dependencies to use this tool:

- [FFmpeg](https://www.ffmpeg.org/download.html)
- Python 2.7+

## Installation

The easiest way to install this tool is to use PIP. No other method of
installation is officially supported at this time.

- PIP ([OS/X Installation Instructions](https://ahmadawais.com/install-pip-macos-os-x-python/))

Installing Audio Slice can be achieved by running the following command once
you have PIP installed:

```
pip install audio-slice
```

## Usage

```
slice --piece <start_in_seconds> <end_in_seconds> <filename>
```

Example:
```
slice --piece 24.3 34.1 --piece 35.3 41.2 never_gonna_give_you_up.mp3
```

A few things to note about using the tool:

1. You can create as many slices of the audio as you need to; even if they overlap. You simply need to add another `--piece <start> <end>` option to the command line.
2. The tool will place the output files in the same directory as the input file.
3. You specify the start and end of a slice in seconds that can include greater precision. (_Ex: 74.3_)
4. Currently, this only works with MP3s.
